## Developers Documents Link

### 1. Project's Share Docs

+ [Geochemistry π Project Member Handbook](https://docs.qq.com/doc/DTm5ZdktaQm11ckxU?u=34aba8ab609e46f9aa84107d300b2894)
+ [Guideline Manual - Geochemistry π](https://docs.qq.com/doc/DQ21IZUdVQktqRWpm?tdsourcetag=s_macqq_grpfile&u=597785a20e2742f78e8e4ae3f87f2f09)
+ [Learning Steps for Newbies - Geochemsitry π](https://docs.qq.com/doc/DTlVEakt2WnJrdkN1?tdsourcetag=s_macqq_grpfile)
+ [Worksheet - Geochemistry π](https://docs.qq.com/sheet/DQ0xIRm5QUElPa09m?tdsourcetag=s_macqq_grpfile&tab=BB08J2)
+ [Technical Materials in Nutstore - Geochemistry π](https://docs.qq.com/sheet/DQ1FwdlFjaEJZbXdq?tdsourcetag=s_macqq_grpfile&tab=BB08J2)
+ [Meeting Minutes - Geochemistry π](https://docs.qq.com/doc/DTm5TaklvWHZRZ2ZE?tdsourcetag=s_macqq_grpfile)
+ [Q&A -Geochemistry π](https://docs.qq.com/doc/DQ05UUmtEUUlpeWRk?tdsourcetag=s_macqq_grpfile)
+ [ML Group Task Assignment Process](https://docs.qq.com/doc/DTk9ialRyd1FRWnFX?u=0451ba1d1a654ecfa28a8bd61c561c22)

### 2. Technical Video (in Bilibili app)

+ [Geochemistry π - Virtual Environment & Packages On Windows - Jianming Zhao (Jamie)](https://www.bilibili.com/video/BV1sL4y1F7hg?spm_id_from=333.999.0.0)
+ [Geochemistry π - Creating and Using Virtual Environments - Can He (Sany)](https://www.bilibili.com/video/BV1C34y1x7sR?spm_id_from=333.999.0.0)
+ [Geochemistry π - How to Run Geochemistry Py v1.0.0-alpha - Can He (Sany)](https://www.bilibili.com/video/BV1i541117dd?spm_id_from=333.999.0.0)
+ [Geochemistry π - How to Collaborate and Provide Bug Report on Geochemistry π Through GitHub - Can He (Sany)](https://www.bilibili.com/video/BV1LA4y1Q7Va?spm_id_from=333.999.0.0)
+ [Geochemistry π - Git Workflow & Coordinating Synchronization - Jianming Zhao (Jamie)](https://www.bilibili.com/video/BV1Sa4y1f74k?spm_id_from=333.999.0.0vd_source=9adcf2c5fdeffe1d11c89d441ef598ba)
+ [Geochemistry π - How to use Github-Desktop in conflict resolution - Qiuhao Zhao (Brad)](https://www.bilibili.com/video/BV18a411D7Tn?spm_id_from=333.999.0.0&vd_source=9adcf2c5fdeffe1d11c89d441ef598ba)
+ [Geochemistry π - Add Algorithm Applications (Pre-Framework Refactoring Version) - Qiuhao Zhao (Brad)](https://www.bilibili.com/video/BV1St4y177rE?spm_id_from=333.999.00vd_source=9adcf2c5fdeffe1d11c89d441ef598ba)
+ [Geochemistry π - Design Philosophy and Practical Implementation of Framework Refactoring - Can He (Sany)](https://www.bilibili.com/video/BV1Ra41137fT?spm_id_from=333.999.0.0vd_source=9adcf2c5fdeffe1d11c89d441ef598ba)

### 3. Leanring Materials in Nutstore

#### Folders Introduction
+ [Leanring Materials](https://www.jianguoyun.com/p/DffdPK4QpJ3BChiCzYcFIAA)
+ [Meeting Video](https://www.jianguoyun.com/p/DYLtUcEQpJ3BChiDzYcFIAA)
+ [Member Self-Introduction](https://www.jianguoyun.com/p/DSde15IQpJ3BChj9zIcFIAA)
+ [Notice](https://www.jianguoyun.com/p/DT6k-bUQpJ3BChiHzYcFIAA)
+ [Technical Video](https://www.jianguoyun.com/p/DanIZEUQpJ3BChiIzYcFIAA)

#### Improtant Files in Nutstore
+ [Framework Architecture（Logic Architecture and Data Path Architecture）Sany_2022-9-18.pdf](https://www.jianguoyun.com/p/DT96oyUQpJ3BChj015EFIAA)
+ [Python Crash Course.pdf](https://www.jianguoyun.com/p/DTivPBIQpJ3BChjv2JEFIAA)
+ [Hands-on-Machine-Learning-with-Scikit-2E.pdf](https://www.jianguoyun.com/p/DYvMspwQpJ3BChjMuocFIAA)
+ [Progit.pdf](https://www.jianguoyun.com/p/DS33MYYQpJ3BChjz15EFIAA)
+ [Python for data analysis.pdf](https://www.jianguoyun.com/p/DfP8zB8QpJ3BChit2JEFIAA)

### 4. Member Notice
+ [template for record videos or presentation.pptx](https://www.jianguoyun.com/p/DW2gjX8QpJ3BChiw2JEFIAA)
+ [Code specification v2.1.2 - Geochemistry π.pdf](https://www.jianguoyun.com/p/DWNHu-wQpJ3BChi12JEFIAA)
+ [cycle_report_template.docx](https://www.jianguoyun.com/p/DcuT0gAQpJ3BChiv2JEFIAA)
+ [Git - Geochemistry π](https://www.jianguoyun.com/p/DbIKxrQQpJ3BChjH2JEFIAA)
